# Archived Tag plugins for Comic Tagger

Tag plugins for [ComicTagger] that have been archived and are no-longer included in ComicTagger by default

[ComicTagger]: https://github.com/comictagger/comictagger
